package com.ruoyi.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.*;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.Result;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.Clazz;
import com.ruoyi.business.domain.req.ClazzQueryReq;
import com.ruoyi.business.domain.req.ClazzSaveReq;
import com.ruoyi.business.domain.req.ClazzEditReq;
import com.ruoyi.business.service.ClazzService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 班级Controller
 *
 * @author muyu
 * @date 2024-04-22
 */
@Api(tags = "班级")
@RestController
@RequestMapping("/business/clazz")
public class ClazzController extends BaseController {

    /**
     * 注入班级Service接口
     */
    @Autowired
    private ClazzService clazzService;

    /**
     * 查询班级列表
     */
    @ApiOperation("获取班级列表")
    @PreAuthorize("@ss.hasPermi('business:clazz:list')")
    @GetMapping("/list")
    public Result<TableDataInfo<Clazz>> list(ClazzQueryReq clazzQueryReq) {
        startPage();
        List<Clazz> list = clazzService.list(Clazz.queryBuild(clazzQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出班级列表
     */
    @ApiOperation("导出班级列表")
    @PreAuthorize("@ss.hasPermi('business:clazz:export')")
    @Log(title = "班级", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Clazz clazz) {
        List<Clazz> list = clazzService.list(clazz);
        ExcelUtil<Clazz> util = new ExcelUtil<Clazz>(Clazz.class);
        util.exportExcel(response, list, "班级数据");
    }

    /**
     * 获取班级详细信息
     */
    @ApiOperation("获取班级详细信息")
    @PreAuthorize("@ss.hasPermi('business:clazz:query')")
    @GetMapping(value = "/{clazzId}")
    @ApiImplicitParam(name = "clazzId", value = "clazzId", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Clazz> getInfo(@PathVariable("clazzId") Long clazzId) {
        return Result.success(clazzService.getById(clazzId));
    }

    /**
     * 新增班级
     */
    @PreAuthorize("@ss.hasPermi('business:clazz:add')")
    @Log(title = "班级", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增班级")
    public Result<String> add(@RequestBody ClazzSaveReq clazzSaveReq) {
        return toAjax(clazzService.save(Clazz.saveBuild(clazzSaveReq)));
    }

    /**
     * 修改班级
     */
    @PreAuthorize("@ss.hasPermi('business:clazz:edit')")
    @Log(title = "班级", businessType = BusinessType.UPDATE)
    @PutMapping("/{clazzId}")
    @ApiOperation("修改班级")
    public Result<String> edit(@PathVariable Long clazzId, @RequestBody ClazzEditReq clazzEditReq) {
        return toAjax(clazzService.updateById(Clazz.editBuild(clazzId,clazzEditReq)));
    }

    /**
     * 删除班级
     */
    @PreAuthorize("@ss.hasPermi('business:clazz:remove')")
    @Log(title = "班级", businessType = BusinessType.DELETE)
	@DeleteMapping("/{clazzIds}")
    @ApiOperation("删除班级")
    @ApiImplicitParam(name = "clazzId", value = "clazzId", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> clazzIds) {
        return toAjax(clazzService.removeBatchByIds(clazzIds));
    }
}
